#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-AVBKWVp8Q0r65z8RLTRGfK
key:                  haskell-language-server-2.3.0.0-AVBKWVp8Q0r65z8RLTRGfK
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  bfaf136fc8e99266c5c782c506a4474b
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-AVBKWVp8Q0r65z8RLTRGfK
depends:
    aeson-pretty-0.8.11-L7mSxewLxt12UvYySeJXz7
    async-2.2.6-BOzBj9OU2RsBdXVaxuDTSw base-4.18.2.1
    base16-bytestring-1.0.2.0-CMK3GBSBriI6YLNV9leCtM
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-5rgQ98jSKHzCY2QD3wsBJS
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-ADJYfTGFlXED5XUWhMGPcf
    githash-0.1.7.0-LCZwCOSUHSa2LjoI5e07WB
    hie-bios-0.12.0-Bctm7iDrVwj9HObaxJuZKi
    hiedb-0.4.3.0-33adS7Q9hqvARS9hi2P1LQ
    hls-alternate-number-format-plugin-2.3.0.0-2y3KLtDZ6vlFTYNe3wb4JB
    hls-cabal-fmt-plugin-2.3.0.0-4HzOi7LqLYAEt498g80zJM
    hls-cabal-plugin-2.3.0.0-I5aQBBBHTmGIj7gAxDKJyU
    hls-call-hierarchy-plugin-2.3.0.0-Kfy4lDd8XKbLBNJXl3Kdv0
    hls-change-type-signature-plugin-2.3.0.0-HemJLRLGUDmjInw8r8N6k
    hls-class-plugin-2.3.0.0-EfscmRTzzh8CVKgzp9rf2u
    hls-code-range-plugin-2.3.0.0-BAJc5WNfv7W7wAVlKO1UuF
    hls-eval-plugin-2.3.0.0-I8vGmEOOCpcB2XZ8MYKwhN
    hls-explicit-fixity-plugin-2.3.0.0-8T9TtglEyfTDC7AzzK3svA
    hls-explicit-imports-plugin-2.3.0.0-5lgdAS2MLkE6R45YOMcgm7
    hls-explicit-record-fields-plugin-2.3.0.0-5u62BOX7VYO9gmNjZZWbVW
    hls-fourmolu-plugin-2.3.0.0-H0Rxx3KC4oMHD6nO6gqWNF
    hls-gadt-plugin-2.3.0.0-Fr2fXPyZSMI1dUiicVCKIm
    hls-graph-2.3.0.0-5TnZntcxnjfFOE8vvh0bLs
    hls-hlint-plugin-2.3.0.0-5UMJdjiWITm4GSRMsHDSC9
    hls-module-name-plugin-2.3.0.0-2xZOaKzrfVSEGR10Uw0wbB
    hls-ormolu-plugin-2.3.0.0-1sECKBZyEQ4DpZkrRsZVUm
    hls-overloaded-record-dot-plugin-2.3.0.0-28eLnFmMqUQCzBMLWO7MFU
    hls-plugin-api-2.3.0.0-Jg5s5m9Ajd96ODSU64WGQ6
    hls-pragmas-plugin-2.3.0.0-HPuNKrgo4LqK4FYbRElrH0
    hls-qualify-imported-names-plugin-2.3.0.0-1aULEdOVHiH6xXAPNw3Tvh
    hls-refactor-plugin-2.3.0.0-HqxB9BZJRKR2yZ9XFDzide
    hls-rename-plugin-2.3.0.0-9llXd9iNj4VH4Q01VagQmY
    hls-retrie-plugin-2.3.0.0-8DwZIzAsgoP3PUSMTJNJ7C
    hls-splice-plugin-2.3.0.0-8uJqOxfgA5OKnpH0HbMzip
    hls-stylish-haskell-plugin-2.3.0.0-HzE7stNQvjPGqJ4h5V74vB
    lsp-2.2.0.0-IKZ4Mpp9MNAHQA77xxW2p1
    optparse-applicative-0.18.1.0-8Us6opzobWeE8qMBykWiRI
    optparse-simple-0.1.1.4-GVDdiishQIyGTa9d3ZHvyy
    prettyprinter-1.7.2-CIJHFVXNQ7ULgjXbroiIfc process-1.6.19.0
    safe-exceptions-0.1.7.4-Ed9tl0V54XFHH60bY3H5co
    sqlite-simple-0.4.19.0-1q0wT82QFMQI1Rq76B20bA text-2.0.2
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

